#!/usr/bin/perl

#
# ?Front end for inserting an image into the DB
#
# Functions necessary:
#
# - Usage
# - Read config??
# - Check if file exists
# - Check if file is in DB already
# - Extract image information
#

use PhotoShelf;

$Prompt = 0;

# settable variables on the command line
# [<flag>, <description>, <db var>, string?, default]

sub Usage {
	print "Usage: $0 [-d] [opts] <files|directory>\n\n";
	print "\t-d\t Prompt for descriptions, etc\n";
	foreach $field (0..$#CmdLine) {
		$flag = $CmdLine[$field][0];
		$var = $CmdLine[$field][1];
		$dbvar = $CmdLine[$field][2];
		print "\t$flag <str>\tUse <str> for $dbvar\n";
	}
	print "If <file>, single file is inserted, if <directory>, whole dir\n";
	print "is inserted into the DB\n";
	exit(0);
}

#
# Give a directory as arg, returns array of full filenames
#
sub recurse_dir {
my ($dir) = @_;
my $wholename;
my (@Files);

	opendir (DIR, "$dir") || die "Cannot open $dir: $!";
	@files = grep { /^[^\. ]/ } readdir(DIR);
	closedir DIR;
	foreach (@files) {
		if (/\.jpg$/i || /\.jpeg$/i || /\.png$/i || /\.tiff$/i) {
			$wholename = $dir . $_;
			push (@Files, $wholename);
		}
	}
	return @Files;
}



$Copyright = "";
$Country = "";
$City = "";

ARGSS:
while ($arg = shift @ARGV) {
	if ($arg =~ /^-d$/) {
		print "Prompting..\n";
		$Prompt = 1;
		next;
	}
	foreach $field (0..$#CmdLine) {
		$flag = $CmdLine[$field][0];
		$var = $CmdLine[$field][1];
		$dbvar = $CmdLine[$field][2];
		next, unless ($flag =~ /^$arg$/);
		$copy = shift(@ARGV);
		$CmdLine[$field][4] = $copy;
		print "Adding $dbvar: $copy\n";
		next ARGSS;
	}
	push(@Files, $arg);
}

if ($#Files < 0) {
	Usage();
	exit(0);
}


if (-d $Files[0]) {
	print "Recursing..\n";
	@Files = recurse_dir($Files[0]);
}

print "Files are: @Files\n";
$Conn = db_connect();

$Owner = $ENV{USER};

if (!defined($Conn)) {
	die "Error connecting to database!";
}

$defaultalbum = AlbumNameId($Owner, "Default");

foreach $file (@Files) {
	$stripped = strip_dir($file);
	if (db_image_exists($stripped)) {
		print "Error: $stripped already in the db, use '-f' to overwrite\n";
		next;
	}
	$info = get_image_info ($file);
	$fmt = $info->{'format'};
	($info->{format}) = $Db_Conn->selectrow_array("SELECT id FROM format WHERE descr = 'fmt'");
	if ($Prompt) {
		$| = 1;
		print "Displaying image..\n";
		system "xv $file &";
		print "Enter image description: "; 
		$Desc = <STDIN>;
		chomp($Desc);
KEYWORDS:
		print "Enter keywords, comma separated: ";
		$Keywords = <STDIN>;
		chomp($Keywords);
		if ($Keywords !~ /^[0-9a-z\.,]*$/i) {
			print "Illegal chars in keywords (A-Z, 0-9, . only)\n";
			goto KEYWORDS;
		}
	}
	$id = database_insert($info);
	db_image_owner($id, $Owner);
	if (!$id) {
		print "Error inserting $file into database\n";
		next;
	}
	$res = repository_insert($file,$id);
	if (!$res) {
		print "Error inserting $file into repository\n";
		database_delete($stripped);
		next;
	}
	$Db_Conn->do("UPDATE photos SET directory = '$res' WHERE imageid = $id");
	AlbumAdd($defaultalbum, $id);
	print "$file done\n";
}
